@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from ctypes import PYFUNCTYPE, Structure, c_char, c_char_p, c_int, py_object
+from ctypes import PYFUNCTYPE, Structure, c_char_p, c_int, py_object
 
 from typing_extensions import Annotated
 
@@ -13,7 +13,7 @@ PyCFunction = PYFUNCTYPE(py_object, py_object, py_object)
 
 @struct
 class PyMethodDef(Structure):
-    ml_name: c_char
+    ml_name: Annotated[bytes, c_char_p]
     ml_meth: PyCFunction
     ml_flags: Annotated[int, c_int]
-    ml_doc: c_char_p
+    ml_doc: Annotated[bytes, c_char_p]
